// System Monitor 4-MUX LCD Driver Solution

#include <Wire.h>                                               // Include Library for I2C Communication

#define Toggle_I2C 0x02                                         // Toggle I2C to trigger Watchdog Timer Reset IN

byte Data_Read, Watchdog_Reset_IN;           

void setup() 
{
  Wire.begin();                                                 // Initiate Wire Library and join I2C bus as a master
}

void loop() 
{
  writeI2C(0x78, 0xF4, 0x01);                                   // Write Data on I2C Virtual Inputs
  delay(10);
  Data_Read = readI2C(0x78, 0xF4);                              // Read Data from I2C Virtual Inputs
  if (Data_Read == 0x01)                                        // Control Structure to trigger Watchdog Timer Reset IN
  {
    Watchdog_Reset_IN = Data_Read ^ Toggle_I2C; 
    writeI2C(0x78, 0xF4, Watchdog_Reset_IN);                    // Write Data on I2C Virtual Inputs to trigger Watchdog Timer 
    writeI2C(0x78, 0xC0, 0xFF);                                 // Control Watchdog Timer Duration
  }
  
  writeI2C(0x78, 0xF4, 0x00);                                   // Turn OFF LCD

// Write data on LCD
  DIG_BLANK();
  delay(500);
  DIG_d();
  delay(500);
  DIG_di();
  delay(500);
  DIG_dia();
  delay(500);
  DIG_dial();
  delay(500);
  DIG_ialo();
  delay(500);
  DIG_alog();
  delay(500);
  DIG_log();
  delay(500);
  DIG_og();
  delay(500);
  DIG_g();
  delay(500);

  writeI2C(0x78, 0xF4, 0x01);                                   // Turn ON LCD
}

// I2C Read Function
int readI2C(byte Slave_Device_Add, byte Reg_Add)
{
  byte Read_Data;
  Wire.beginTransmission(Slave_Device_Add);                     // Start I2C read with Slave Device Address
  Wire.write(Reg_Add);                                          // Write Register Address
  Wire.endTransmission(false);                                  // End Transmission
  Wire.requestFrom(Slave_Device_Add, 1);                        // Read Bytes from Register Address
  while(Wire.available())
  {
    Read_Data = Wire.read();                                    // Read Data
  }
  return Read_Data;
}

//I2C Write Function
void writeI2C(byte Slave_Add, byte Reg_Add, byte Write_Data) 
{
  Wire.beginTransmission(Slave_Add);                            // Start I2C write with Slave Device Address
  Wire.write(Reg_Add);                                          // Write Redister Address
  Wire.write(Write_Data);                                       // Write Data
  Wire.endTransmission();                                       // End Transmission
}

// LCD Data Functions
void DIG_BLANK()                                                // Display Blank
{
  writeI2C(0x78, 0xD0, 0xFF);
  writeI2C(0x78, 0xD1, 0xFF);
  writeI2C(0x78, 0xD2, 0xFF);
  writeI2C(0x78, 0xD3, 0xFF);
  writeI2C(0x78, 0xD4, 0x00);
  writeI2C(0x78, 0xD5, 0x00);
  writeI2C(0x78, 0xD6, 0x00);
  writeI2C(0x78, 0xD7, 0x00);  
}

void DIG_d()                                                    // Display d
{
  writeI2C(0x78, 0xD0, 0xBF);
  writeI2C(0x78, 0xD1, 0x3F);
  writeI2C(0x78, 0xD2, 0x3F);
  writeI2C(0x78, 0xD3, 0xFF);
  writeI2C(0x78, 0xD4, 0x40);
  writeI2C(0x78, 0xD5, 0xC0);
  writeI2C(0x78, 0xD6, 0xC0);
  writeI2C(0x78, 0xD7, 0x00);
}

void DIG_di()                                                   // Display di
{
  writeI2C(0x78, 0xD0, 0xEF);
  writeI2C(0x78, 0xD1, 0x4F);
  writeI2C(0x78, 0xD2, 0x4F);
  writeI2C(0x78, 0xD3, 0xFF);
  writeI2C(0x78, 0xD4, 0x10);
  writeI2C(0x78, 0xD5, 0xB0);
  writeI2C(0x78, 0xD6, 0xB0);
  writeI2C(0x78, 0xD7, 0x00);
}

void DIG_dia()                                                  // Display dia
{
  writeI2C(0x78, 0xD0, 0xBB);
  writeI2C(0x78, 0xD1, 0x13);
  writeI2C(0x78, 0xD2, 0x13);
  writeI2C(0x78, 0xD3, 0x7F);
  writeI2C(0x78, 0xD4, 0x44);
  writeI2C(0x78, 0xD5, 0xEC);
  writeI2C(0x78, 0xD6, 0xEC);
  writeI2C(0x78, 0xD7, 0x80);
}

void DIG_dial()                                                 // Display dial
{
  writeI2C(0x78, 0xD0, 0xAE);
  writeI2C(0x78, 0xD1, 0x84);
  writeI2C(0x78, 0xD2, 0xC4);
  writeI2C(0x78, 0xD3, 0x9F);
  writeI2C(0x78, 0xD4, 0x51);
  writeI2C(0x78, 0xD5, 0x7B);
  writeI2C(0x78, 0xD6, 0x3B);
  writeI2C(0x78, 0xD7, 0x60);
}

void DIG_ialo()                                                 // Display ialo
{
  writeI2C(0x78, 0xD0, 0xAB);
  writeI2C(0x78, 0xD1, 0x21);
  writeI2C(0x78, 0xD2, 0xB1);
  writeI2C(0x78, 0xD3, 0xE7);
  writeI2C(0x78, 0xD4, 0x54);
  writeI2C(0x78, 0xD5, 0xDE);
  writeI2C(0x78, 0xD6, 0x4E);
  writeI2C(0x78, 0xD7, 0x18);
}

void DIG_alog()                                                 // Display alog
{
  writeI2C(0x78, 0xD0, 0xAA);
  writeI2C(0x78, 0xD1, 0x48);
  writeI2C(0x78, 0xD2, 0x2C);
  writeI2C(0x78, 0xD3, 0x39);
  writeI2C(0x78, 0xD4, 0x55);
  writeI2C(0x78, 0xD5, 0xB7);
  writeI2C(0x78, 0xD6, 0xD3);
  writeI2C(0x78, 0xD7, 0xC6);
}

void DIG_log()                                                  // Display log
{
  writeI2C(0x78, 0xD0, 0xEA);
  writeI2C(0x78, 0xD1, 0xD2);
  writeI2C(0x78, 0xD2, 0xCB);
  writeI2C(0x78, 0xD3, 0xCE);
  writeI2C(0x78, 0xD4, 0x15);
  writeI2C(0x78, 0xD5, 0x2D);
  writeI2C(0x78, 0xD6, 0x34);
  writeI2C(0x78, 0xD7, 0x31);
}

void DIG_og()                                                   // Display og
{
  writeI2C(0x78, 0xD0, 0xFA);
  writeI2C(0x78, 0xD1, 0xF4);
  writeI2C(0x78, 0xD2, 0xF2);
  writeI2C(0x78, 0xD3, 0xF3);
  writeI2C(0x78, 0xD4, 0x05);
  writeI2C(0x78, 0xD5, 0x0B);
  writeI2C(0x78, 0xD6, 0x0D);
  writeI2C(0x78, 0xD7, 0x0C);
}

void DIG_g()                                                    // Display g
{
  writeI2C(0x78, 0xD0, 0xFE);
  writeI2C(0x78, 0xD1, 0xFD);
  writeI2C(0x78, 0xD2, 0xFC);
  writeI2C(0x78, 0xD3, 0xFC);
  writeI2C(0x78, 0xD4, 0x01);
  writeI2C(0x78, 0xD5, 0x02);
  writeI2C(0x78, 0xD6, 0x03);
  writeI2C(0x78, 0xD7, 0x03);
} 




